#!/bin/sh

# Default settings
PLATFORM=x86

die() {
  echo "$0: ERROR: $1!"
  exit 1
}

usage() {
  cat << __EOT__
Usage: $0 [option...]
Where option is one or more of the following:
* s3c24xx            - Build for Samsung s3c24xx platform
* titan2             - Build for Sirf titan2 platform
* s3c64xx            - Build for Samsung s3c24xx platform
* at4x0a             - Build for Centrality/SiRF at4x0a platform
* x86                - Build for Linux Desktop (default)
* help               - this message

__EOT__
 exit 1
}

# Parse command line arguments
while test -n "$1"; do
  case "$1" in
  s3c24xx|at4x0a|s3c64xx|x86|titan2)
    PLATFORM="$1"
    ;;
  help)
    usage
    ;;
  *)
    echo "$0: Unknown argument $1."
    usage
    ;;
  esac
  shift
done


case ${PLATFORM} in
	x86)
		# Force compilation of a 32 bits x86 application.
		# 32 bits, because DataCore cannot deal with 64 bits values,
		make distclean 2>/dev/null
		./configure CFLAGS="-m32" CXXFLAGS="-m32" LDFLAGS="-m32" \
			--prefix=${PWD}/../../dist/1.12.0 --exec-prefix=${PWD}/../../dist/1.12.0/${PLATFORM}
		;;
	s3c24xx)
		make distclean 2>/dev/null
		./configure --host=arm-linux \
			--prefix=${PWD}/../../dist/1.12.0 --exec-prefix=${PWD}/../../dist/1.12.0/${PLATFORM}
		;;
	at4x0a)
		make distclean 2>/dev/null
		./configure --host=arm-at4x0a-linux-gnueabi \
			--prefix=${PWD}/../../dist/1.12.0 --exec-prefix=${PWD}/../../dist/1.12.0/${PLATFORM}
		;;
	s3c64xx|titan2)
		make distclean 2>/dev/null
		./configure --host=arm-none-linux-gnueabi \
			--prefix=${PWD}/../../dist/1.12.0 --exec-prefix=${PWD}/../../dist/1.12.0/${PLATFORM}
		;;
	*)
		die "Unknown platform: ${PLATFORM}"
		;;
esac

if [ $? = 0 ]; then
	make && make install
else
	die "configure for ${PLATFORM} failed, sorry"
fi

if [ $? = 0 ]; then
	echo "Build succeeded, bye"
fi

